#
# spec file for package irda
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d
Name:           irda
Version:        0.9.18
Release:        bp156.4.5
Summary:        Necessary Tools for Using the Infrared Port
License:        GPL-2.0-or-later
Group:          Hardware/Other
Url:            http://irda.sourceforge.net
Source:         http://sourceforge.net/projects/irda/files/irda-utils/%{version}/irda-utils-%{version}.tar.gz
Source1:        52-irda.rules
Source2:        irattach.service
Source3:        irda-0.9.18.sysconfig
Source4:        irda-rpmlintrc
Patch1:         irda-0.9.18-psion-no-strict-aliasing.diff
Patch2:         irda-0.9.18-irnetd-install.diff
Patch3:         irda-0.9.18-findchip-ppc.diff
Patch4:         irda-0.9.18-irdadump-flush-stdout.diff
Patch5:         irda-utils-0.9.18-fix-irkbd-makefile.diff
Patch6:         irda-utils-0.9.16-fix-off-by-one.diff
Patch7:         irda-libpci_with_libz.diff
Patch8:         irda-0.9.18-buildroot.diff
Patch9:         irda-0.9.18-no-findchip-smc.diff
Patch10:        irda-optflags.diff
Patch11:        irda-fix_link_command.diff
Patch12:        irda-exit_on_error.diff
Patch13:        irda-irdaping_no_strict_aliasing.diff
Patch14:        irda-no_std_paths.diff
Patch15:        irda-parseoldasssysconfig.patch
Patch16:        irda-fix_build_with_recent_kernels.diff
BuildRequires:  glib2-devel
BuildRequires:  linux-kernel-headers
BuildRequires:  pciutils-devel
BuildRequires:  pkgconfig(libHX)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Requires(pre):  %fillup_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
This package contains all necessary scripts and programs for setting up
and using the infrared port for printing or communicating. The start
and stop scripts are prepared to access the UART emulation ('SIR' mode)
with 115 kbit/s data transfer rate. This is supported by most laptops
with an infrared interface.

After starting the infrared protocol manager 'irmanger' with the
command 'rcirda start', you can send data to your printer using the
device file /dev/irlpt0. If you like to talk to other computers with
infrared interface or to a mobile phone, you can use the serial
emulation provided by the device file /dev/ircomm0.

Take a look at the README file located in
%{_docdir}/irda/README and the IRDA HOWTO in
%{_datadir}/doc/howto/en/IR-HOWTO.gz. If the infrared port on your
laptop is located on an IO or IRQ address other than IO address 0x2f8
(/dev/ttyS1) or interrupt 3, you should use YaST to change the
variables IRDA_PORT and IRDA_IRQ in the configuration file
%{_sysconfdir}/rc.config.

%prep
%setup -q -n irda-utils-%{version}
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7
%patch8
%patch9
%patch10
%patch11
%patch12
%patch13
%patch14
%patch15
%patch16 -p1

%build
make %{?_smp_mflags} V=1 RPM_OPT_FLAGS="%{optflags} -fgnu89-inline -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64" INITD=%{_sysconfdir}/init.d ROOT=%{buildroot} all

%install
install -d -m 755 %{buildroot}%{_prefix}/sbin
install -d -m 755 %{buildroot}%{_prefix}/bin
install -d -m 755 %{buildroot}%{_docdir}/irda
install -d -m 755 %{buildroot}%{_fillupdir}
make INITD=%{_sysconfdir}/init.d \
             DOCDIR=%{_defaultdocdir}/irda \
             ROOT=%{buildroot} \
	MANDIR=%{_mandir} \
	install
rm %{buildroot}%{_sysconfdir}/sysconfig/irda %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifcfg-irlan0
rmdir %{buildroot}%{_sysconfdir}/sysconfig/network-scripts
#documentation, READMEs
install -m 644 README %{buildroot}%{_docdir}/irda/
install -m 644 ethereal/README %{buildroot}%{_docdir}/irda/README.ethereal
install -m 644 irattach/README %{buildroot}%{_docdir}/irda/README.irattach
install -m 644 irdadump/README %{buildroot}%{_docdir}/irda/README.irdadump
install -m 644 ethereal/README %{buildroot}%{_docdir}/irda/README.ethereal
install -m 644 irdaping/README %{buildroot}%{_docdir}/irda/README.irdaping
install -m 644 ethereal/README %{buildroot}%{_docdir}/irda/README.ethereal
install -m 644 irsockets/README %{buildroot}%{_docdir}/irda/README.irsockets
install -m 644 tekram/README %{buildroot}%{_docdir}/irda/README.tekram
# udev stuff
install -D -m 644 %{SOURCE1} %{buildroot}%{_udevrulesdir}/52-irda.rules
# sysconfig template
install -m 644 %{SOURCE3} %{buildroot}%{_fillupdir}/sysconfig.irda
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/irattach.service
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rcirattach

%pre
%service_add_pre irattach.service

%post
%{fillup_only -n irda}
%service_add_post irattach.service
%udev_rules_update

%preun
%service_del_preun irattach.service

%postun
%service_del_postun irattach.service

%files
%defattr(-,root,root)
%doc %{_docdir}/irda
%{_sbindir}/*
%{_bindir}/*
%doc %{_mandir}/man4/*
%doc %{_mandir}/man7/*
%doc %{_mandir}/man8/*
%{_fillupdir}/sysconfig.irda
%{_udevrulesdir}/52-irda.rules
%{_unitdir}/irattach.service

%changelog
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Wed Sep 22 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * irattach.service
* Mon Aug 26 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add irda-fix_build_with_recent_kernels.diff
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Jun  9 2015 schwab@suse.de
- Force gnu89 inline semantics
* Fri Apr  3 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner.
- Use macro to refresh udev rules
- Use url for source
- Creanet rcservice symlink
* Thu Apr  4 2013 crrodriguez@opensuse.org
- fix braino in udev rule, missing comma. and TAG attribute.
* Thu Apr  4 2013 crrodriguez@opensuse.org
- irda-parseoldasssysconfig.patch + udev rules + irattach.service:
  * Add systemd support
  * remove sysvinit support(this change requires udev & systemd combo)
* Tue Feb 23 2010 aj@suse.de
- Change udev rules to remove deprecated SYSFS.
* Sat Jan  2 2010 vuntz@opensuse.org
- Change gtk1-compat-devel BuildRequires to glib2-devel. Nothing is
  using GTK+ 1.x, and it also makes it possible to compile
  irdadump.
* Thu Nov 26 2009 pth@suse.de
- Call 'pkg-config --libs' after the objects to link (bnc#558534)
- Remove '-' from recursive make invocation to exit on errors
  during build or install.
- Add Short-Description to the init file.
- Add a rpmlintrc file to suppres the erroneous warning about
  buildroot usage.
- Don't pass paths to the linker where it will search by default.
* Tue Aug 26 2008 meissner@suse.de
- fixed init script issues
- use rpm_opt_flags everywhere
* Sun Jan 27 2008 meissner@suse.de
- disable build of findchip and smcinit, this is done/shoube be done
  in kernel.
* Sun Feb 11 2007 ro@suse.de
- fix build as non-root
- link with libz when using libpci
* Mon Aug  7 2006 seife@suse.de
- update to 0.9.18, which includes:
  - fixes and improvements to irdadump
  - smcinit has been integrated
  - support TOIM3232 dongle
  - ability to run irattach in the foreground
  - irdadump can read and write libpcap files
  - new manpages
- include irnetd
- package various README files
- misc. packaging cleanups
* Tue Feb  7 2006 sscheler@suse.de
- fixed "directories not owned by a package"-problem
* Tue Feb  7 2006 sscheler@suse.de
- added udev rule for IrDA (#60496)
* Tue Jan 31 2006 sscheler@suse.de
- fixed irkbd build problems (#127868)
- fixed irattach off-by-one error (#131517)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 sbrabec@suse.cz
- Force glib2 using gtk1-compat-devel.
* Thu Sep  1 2005 zoz@suse.de
- load ircomm-tty in start script (bug 113290)
* Thu Sep  9 2004 zoz@suse.de
- added patch irda.flush_irdadump_output.diff that makes irdadump
  write its output properly through pipes. (Bug 44657)
* Mon Sep  6 2004 zoz@suse.de
- Changed MAX_BAUD_RATE to IRDA_MAX_BAUD_RATE
* Tue Aug 17 2004 hare@suse.de
- Add MAX_BAUD_RATE option for Nokia phones (#40814).
* Mon Mar 15 2004 behlert@suse.de
- updated to 0.9.16 which should work with Kernel 2.6 [#35746]
- still TODO: spec-file needs rework
* Mon Sep  1 2003 mmj@suse.de
- Add sysconfig metadata [#28884]
* Thu Feb 20 2003 mmj@suse.de
- Add sysconfig metadata [#22649]
* Mon Aug 19 2002 jg@suse.de
- fixed init info of /etc/init.d/irda
* Tue Aug 13 2002 zoz@suse.de
- added PreReq: %%insserv_prereq %%fillup_prereq
* Thu Jul 11 2002 kukuk@suse.de
- Change require serial to should-start setserial
* Wed Feb 27 2002 zoz@suse.de
- made init script LSB compliant
- changed comment in sysconfig/irda (Bug 12068)
* Mon Jan 14 2002 ro@suse.de
- removed START_IRDA and moved rest to /etc/sysconfig/irda
* Tue Jun 26 2001 ro@suse.de
- make it accept libtool-1.4
* Wed Apr 11 2001 zoz@suse.de
- added irda manpages from mobilix.org
- made filelist generic
- removed %%{?suse_check}
* Sat Jan  6 2001 zoz@suse.de
- updated status section in rcirda
* Mon Dec 11 2000 kukuk@suse.de
- Adjust sparc patch
* Tue Dec  5 2000 zoz@suse.de
- excluded findchip for all non i386
* Sun Dec  3 2000 zoz@suse.de
- update to 0.9.13
- removed /etc/irda/
- moved /sbin/init.d/irda to /etc/init.d/irda
- added INIT INFO to rcirda and moved it to /etc/init.d/irda
- removed START/STOP-links, added insserv
* Mon Nov  6 2000 ro@suse.de
- fixed neededforbuild
* Sat Jul  8 2000 kukuk@suse.de
- Don't build findchip on SPARC
* Wed Jun  7 2000 ro@suse.de
- doc relocation
* Wed Feb 16 2000 uli@suse.de
- added support for PPC (untested, might work on CHRP and PReP)
* Mon Feb 14 2000 cg@suse.de
- update to 0.9.9
* Fri Oct 29 1999 cg@suse.de
- adjusted owner and group of the devices to root.lp (/dev/irlpt0) and
  root.uucp (/dev/ircomm0).
- modified network start/stop skript a little bit: Removed the default setup
  from "bootp" on the irlan interface to "no configuration" (Behaves now
  like the skript in the PCMCIA package)
* Fri Oct 15 1999 ro@suse.de
- rebuild binary objects (at least for non-x86)
* Tue Oct 12 1999 cg@suse.de
- Forget to include the fillup rc.config skript in the post
  install section - fixed
* Mon Oct  4 1999 cg@suse.de
- adjusted scripts in /etc/irda, added creation of dev/ircomm and /dev/irlpt
- created start/stop script in scripts, will be installed in /sbin/init.d,
  /usr/sbin/rcirda runlevel start/stop links will be created for runlevel 2
  and 3
- fillup creates START_IRDA, IRDA_PORT, IRDA_IRQ variables in etc/rc.config.
  Default ist
  START_IRQ=no
  IRDA_PORT=/dev/ttyS1
  IRDA_IRQ=3
  which works for the mosts Laptops flawlessly (but only UART SIR mode, not
  FIR - manual editing of /etc/irda/drivers is necessary to change this)
- changed etc/network and etc/network.opts to be similar to the PCMCIA
  scripts.
- irobex tools are installed in /usr/bin and not in /bin
- Documentation is copied to /usr/doc/packages/irda
